Summary: DNSSEC key and zone management software
Name: opendnssec
Version: 1.3.6
Release: 1%{?dist}
License: BSD
Url: http://www.opendnssec.org/
Source: http://www.opendnssec.org/files/source/%{name}-%{version}.tar.gz
Source1: ods-signerd.init
Source2: ods-enforcerd.init
Source3: ods.sysconfig
Patch1: conf-xml.patch
Group: Applications/System
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Requires: opencryptoki, softhsm, rubygem-dnsruby
BuildRequires: ldns-devel >= 1.6.9, sqlite-devel rubygem-dnsruby >= 1.53 libxml2-devel CUnit-devel, ruby
Requires(pre): shadow-utils

%description
OpenDNSSEC was created as an open-source turn-key solution for DNSSEC.
It secures zone data just before it is published in an authoritative
name server. It requires a PKCS#11 crypto module library, such as softhsm

%prep
%setup -q 
%patch1 -p0

%build
%configure --with-ldns=%{_libdir}
make %{?_smp_mflags}

%check
# Requires sample db not shipped with upstream
# make check

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} install
# fixup locations in upstream config file
sed -i "s:libsofthsm.so:softhsm/libsofthsm.so:" %{buildroot}/%{_sysconfdir}/opendnssec/conf.xml
sed -i "s:/usr/lib/libpkcs11.so:%{_libdir}/opencryptoki/PKCS11_API.so:" %{buildroot}/%{_sysconfdir}/opendnssec/conf.xml
mkdir -p %{buildroot}/var/opendnssec/{tmp,signed,signconf}

# cleanup sample files
rm -f %{buildroot}/%{_sysconfdir}/opendnssec/*.sample

# install our own initscripts
install -d -m 0755 %{buildroot}/%{_sysconfdir}/sysconfig 
install -d -m 0755 %{buildroot}%{_initrddir}
install -m 0755 %{SOURCE1} %{buildroot}/%{_initrddir}/ods-signerd
install -m 0755 %{SOURCE2} %{buildroot}/%{_initrddir}/ods-enforcerd
install -m 0644 %{SOURCE3} %{buildroot}/%{_sysconfdir}/sysconfig/ods

%clean
rm -rf %{buildroot}

%files 
%defattr(-,root,root)
%attr(0750,root,ods) %dir %{_sysconfdir}/opendnssec
%attr(0770,root,ods) %dir %{_localstatedir}/opendnssec
%attr(0770,root,ods) %dir %{_localstatedir}/opendnssec/tmp
%attr(0770,root,ods) %dir %{_localstatedir}/opendnssec/signed
%attr(0770,root,ods) %dir %{_localstatedir}/opendnssec/signconf
%attr(0660,root,ods) %config(noreplace) %{_sysconfdir}/opendnssec/*.xml
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/ods
%attr(0755,root,root) %{_initrddir}/ods-signerd
%attr(0755,root,root) %{_initrddir}/ods-enforcerd
%attr(0755,root,root) %dir %{_libdir}/opendnssec
%attr(0755,root,root) %{_libdir}/opendnssec/*.rb
%attr(0755,root,root) %{_libdir}/opendnssec/kasp_auditor/*.rb
%attr(0770,root,ods) %ghost %dir %{_localstatedir}/run/opendnssec
%doc NEWS README
%{_mandir}/*/*
%{_sbindir}/*
%{_bindir}/*
%attr(0755,root,root) %dir %{_prefix}/share/%{name}
%{_prefix}/share/%{name}/*

%pre
getent group ods >/dev/null || groupadd -r ods
getent passwd ods >/dev/null || \
useradd -r -g ods -d /etc/opendnssec -s /sbin/nologin \
-c "opendnssec daemon account" ods
exit 0

%post
/sbin/chkconfig --add ods-signerd
/sbin/chkconfig --add ods-enforcerd
# Initialise a slot on the softhsm on first install
if [ "$1" -eq 1 ]; then
        softhsm --init-token --slot 0 --label "OpenDNSSEC" --pin 1234 --so-pin 1234
fi

%preun
if [ $1 -eq 0 ]; then
        /sbin/service ods-signerd stop
        /sbin/service ods-enforcerd stop
        /sbin/chkconfig --del ods-signerd
        /sbin/chkconfig --del ods-enforcerd
fi

%postun
if [ "$1" -ge "1" ]; then
  /sbin/service ods-signerd condrestart
  /sbin/service ods-enforcerd condrestart
fi

%changelog
* Thu Nov 24 2011 root - 1.3.2-6
- Added rubygem-dnsruby requires as rpm does not pick it up automatically

* Tue Nov 22 2011 root - 1.3.2-5
- Added /var/opendnssec/signconf/ /as this temp dir is needed

* Mon Nov 21 2011 Paul Wouters <paul@xelerance.com> - 1.3.2-4
- Added /var/opendnssec/signed/ as this is the default output dir

* Sun Nov 20 2011 Paul Wouters <paul@xelerance.com> - 1.3.2-3
- Add ods user for opendnssec tasks
- Added initscripts and services for ods-signerd and ods-enforcerd
- Initialise OpenDNSSEC softhsm token on first install

* Wed Oct 05 2011 Paul Wouters <paul@xelerance.com> - 1.3.2-1
- Updated to 1.3.2
- Added dependancies on opencryptoki and softhsm
- Don't install duplicate unreadable .sample files
- Fix upstream conf.xml to point to actually used library paths

* Thu Mar  3 2011 Paul Wouters <paul@xelerance.com> - 1.2.0-1
- Initial package for Fedora 
